@@ -36,7 +36,7 @@ static const int _kimap_sslErrorUiData = qRegisterMetaType<KSslErrorUiData>();
 
 SessionThread::SessionThread(const QString &hostName, quint16 port)
     : QObject(), m_hostName(hostName), m_port(port),
-      m_socket(Q_NULLPTR), m_stream(nullptr), m_mutex(),
+      m_socket(nullptr), m_stream(nullptr), m_mutex(),
       m_encryptedMode(false)
 {
     // Just like the Qt docs now recommend, for event-driven threads:
@@ -125,7 +125,7 @@ void SessionThread::readMessage()
 
         emit responseReceived(message);
 
-    } catch (KIMAP::ImapParserException e) {
+    } catch (const KIMAP::ImapParserException &e) {
         qCWarning(KIMAP_LOG) << "The stream parser raised an exception:" << e.what();
     }
 
@@ -157,7 +157,7 @@ void SessionThread::doCloseSocket()
 void SessionThread::reconnect()
 {
     Q_ASSERT(QThread::currentThread() == thread());
-    if (m_socket == Q_NULLPTR) { // threadQuit already called
+    if (m_socket == nullptr) { // threadQuit already called
         return;
     }
     if (m_socket->state() != SessionSocket::ConnectedState &&
@@ -205,9 +205,9 @@ void SessionThread::threadQuit()
 {
     Q_ASSERT(QThread::currentThread() == thread());
     delete m_stream;
-    m_stream = Q_NULLPTR;
+    m_stream = nullptr;
     delete m_socket;
-    m_socket = Q_NULLPTR;
+    m_socket = nullptr;
     thread()->quit();
 }
 
@@ -258,7 +258,7 @@ void SessionThread::sslConnected()
     }
     KSslCipher cipher = m_socket->sessionCipher();
 
-    if (m_socket->sslErrors().count() > 0 ||
+    if (!m_socket->sslErrors().isEmpty() ||
             m_socket->encryptionMode() != KTcpSocket::SslClientMode ||
             cipher.isNull() || cipher.usedBits() == 0) {
         qCDebug(KIMAP_LOG) << "Initial SSL handshake failed. cipher.isNull() is" << cipher.isNull()
